==> senior_design_system-0.21.4.tar.gz: example/lib/pages/switch.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class SwitchExample extends StatefulWidget {
  const SwitchExample({Key? key}) : super(key: key);

  @override
  _SwitchExampleState createState() => _SwitchExampleState();
}

class _SwitchExampleState extends State<SwitchExample> {
  bool _isDisabled = false;
  bool _optionOne = false;
  bool _optionTwo = false;
  bool _optionThree = false;
  bool _optionFour = false;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Switch',
      child: SingleChildScrollView(
        child: Column(
          children: [
            SeniorSwitch(
              title: 'Habilitar botões',
              value: !_isDisabled,
              onChanged: (value) {
                if (value == null) return;
                setState(() {
                  _isDisabled = !value;
                });
              },
              titlePosition: SeniorSwitchTitlePosition.right,
            ),
            Padding(
              padding: const EdgeInsets.all(16.0),
              child: Column(
                children: [
                  SeniorSwitch(
                    title: 'Receber notificações',
                    value: _optionOne,
                    onChanged: (value) {
                      if (value == null) return;
                      setState(() {
                        _optionOne = value;
                      });
                    },
                    disabled: _isDisabled,
                  ),
                  SeniorSwitch(
                    title: 'Enviar com Enter',
                    value: _optionTwo,
                    onChanged: (value) {
                      if (value == null) return;
                      setState(() {
                        _optionTwo = value;
                      });
                    },
                    disabled: _isDisabled,
                    titlePosition: SeniorSwitchTitlePosition.right,
                  ),
                  SeniorSwitch(
                    title: 'Atualizar automaticamente',
                    value: _optionThree,
                    onChanged: (value) {
                      if (value == null) return;
                      setState(() {
                        _optionThree = value;
                      });
                    },
                    disabled: _isDisabled,
                    fullLenght: true,
                  ),
                  SeniorSwitch(
                    title: 'Salvar automaticamente',
                    value: _optionFour,
                    onChanged: (value) {
                      if (value == null) return;
                      setState(() {
                        _optionFour = value;
                      });
                    },
                    disabled: _isDisabled,
                    fullLenght: true,
                    titlePosition: SeniorSwitchTitlePosition.right,
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> senior_design_system-6.0.0.tar.gz: example/lib/pages/switch.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class SwitchExample extends StatefulWidget {
  const SwitchExample({Key? key}) : super(key: key);

  @override
  _SwitchExampleState createState() => _SwitchExampleState();
}

class _SwitchExampleState extends State<SwitchExample> {
  bool _isDisabled = false;
  bool _optionOne = false;
  bool _optionTwo = false;
  bool _optionThree = false;
  bool _optionFour = false;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Switch',
      child: SingleChildScrollView(
        child: Column(
          children: [
            SeniorSwitch(
              title: 'Habilitar botões',
              value: !_isDisabled,
              onChanged: (value) {
                if (value == null) {
                  return;
                }
                setState(() {
                  _isDisabled = !value;
                });
              },
              titlePosition: SeniorSwitchTitlePosition.right,
            ),
            Padding(
              padding: const EdgeInsets.all(16.0),
              child: Column(
                children: [
                  SeniorSwitch(
                    title: 'Receber notificações',
                    value: _optionOne,
                    onChanged: (value) {
                      if (value == null) {
                        return;
                      }
                      setState(() {
                        _optionOne = value;
                      });
                    },
                    disabled: _isDisabled,
                  ),
                  SeniorSwitch(
                    title: 'Enviar com Enter',
                    value: _optionTwo,
                    onChanged: (value) {
                      if (value == null) {
                        return;
                      }
                      setState(() {
                        _optionTwo = value;
                      });
                    },
                    disabled: _isDisabled,
                    titlePosition: SeniorSwitchTitlePosition.right,
                  ),
                  SeniorSwitch(
                    title: 'Atualizar automaticamente',
                    value: _optionThree,
                    onChanged: (value) {
                      if (value == null) {
                        return;
                      }
                      setState(() {
                        _optionThree = value;
                      });
                    },
                    disabled: _isDisabled,
                    fullLenght: true,
                  ),
                  SeniorSwitch(
                    title: 'Salvar automaticamente',
                    value: _optionFour,
                    onChanged: (value) {
                      if (value == null) {
                        return;
                      }
                      setState(() {
                        _optionFour = value;
                      });
                    },
                    disabled: _isDisabled,
                    fullLenght: true,
                    titlePosition: SeniorSwitchTitlePosition.right,
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
